==> kubernetes-model-autoscaling-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HPAScalingPolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HPAScalingPolicyFluentImpl<A extends HPAScalingPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HPAScalingPolicyFluent<A> {

    private Integer periodSeconds;
    private String type;
    private Integer value;

    public HPAScalingPolicyFluentImpl() {
    }

    public HPAScalingPolicyFluentImpl(HPAScalingPolicy instance) {
        this.withPeriodSeconds(instance.getPeriodSeconds()); 
        this.withType(instance.getType()); 
        this.withValue(instance.getValue()); 
    }

    public Integer getPeriodSeconds() {
        return this.periodSeconds;
    }

    public A withPeriodSeconds(Integer periodSeconds) {
        this.periodSeconds=periodSeconds; return (A) this;
    }

    public Boolean hasPeriodSeconds() {
        return this.periodSeconds != null;
    }

    public A withNewPeriodSeconds(String arg1) {
        return (A)withPeriodSeconds(new Integer(arg1));
    }

    public A withNewPeriodSeconds(int arg1) {
        return (A)withPeriodSeconds(new Integer(arg1));
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public Integer getValue() {
        return this.value;
    }

    public A withValue(Integer value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(String arg1) {
        return (A)withValue(new Integer(arg1));
    }

    public A withNewValue(int arg1) {
        return (A)withValue(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HPAScalingPolicyFluentImpl that = (HPAScalingPolicyFluentImpl) o;
        if (periodSeconds != null ? !periodSeconds.equals(that.periodSeconds) :that.periodSeconds != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(periodSeconds,  type,  value,  super.hashCode());
    }

}

==> kubernetes-model-autoscaling-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HPAScalingPolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HPAScalingPolicyFluentImpl<A extends HPAScalingPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HPAScalingPolicyFluent<A> {

    private Integer periodSeconds;
    private String type;
    private Integer value;

    public HPAScalingPolicyFluentImpl() {
    }

    public HPAScalingPolicyFluentImpl(HPAScalingPolicy instance) {
        this.withPeriodSeconds(instance.getPeriodSeconds()); 
        this.withType(instance.getType()); 
        this.withValue(instance.getValue()); 
    }

    public Integer getPeriodSeconds() {
        return this.periodSeconds;
    }

    public A withPeriodSeconds(Integer periodSeconds) {
        this.periodSeconds=periodSeconds; return (A) this;
    }

    public Boolean hasPeriodSeconds() {
        return this.periodSeconds != null;
    }

    public A withNewPeriodSeconds(int arg1) {
        return (A)withPeriodSeconds(new Integer(arg1));
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(int[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(char[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(byte[] arg1,int arg2) {
        return (A)withType(new String(arg1, arg2));
    }

    public A withNewType(byte[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(char[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public Integer getValue() {
        return this.value;
    }

    public A withValue(Integer value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(int arg1) {
        return (A)withValue(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HPAScalingPolicyFluentImpl that = (HPAScalingPolicyFluentImpl) o;
        if (periodSeconds != null ? !periodSeconds.equals(that.periodSeconds) :that.periodSeconds != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(periodSeconds,  type,  value,  super.hashCode());
    }

}
